@@ -14,6 +14,7 @@
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
+#' @param x_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the x scale. Defaults to FALSE.
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
 #' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
 #' @param x_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5. 
@@ -50,7 +51,9 @@
 #'   group_by(species) %>% 
 #'   summarise(body_mass_g = mean(body_mass_g, na.rm = TRUE))  
 #' 
-#' gg_hbar(plot_data, body_mass_g, species)
+#' gg_hbar(plot_data, 
+#'         x_var = body_mass_g, 
+#'         y_var = species)
 #' 
 gg_hbar <- function(data,
                     x_var,
@@ -66,6 +69,7 @@ gg_hbar <- function(data,
                     subtitle_wrap = 80,
                     x_balance = FALSE,
                     x_expand = NULL,
+                    x_gridlines_minor = FALSE,
                     x_labels = waiver(),
                     x_na = TRUE,
                     x_pretty_n = 5,
@@ -154,7 +158,7 @@ gg_hbar <- function(data,
   bar_width <- bar_unit * width
   
   plot <- ggplot(data) +
-    theme_hbar(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
+    theme_x_gridlines(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
     geom_col(aes(x = !!y_var, y = !!x_var, text = !!text_var), 
              col = pal, 
              fill = pal, 
@@ -249,6 +253,11 @@ gg_hbar <- function(data,
       geom_hline(yintercept = 0, colour = "#323232", size = 0.3)
   }
   
+  if (x_gridlines_minor == TRUE) {
+    plot <- plot +
+      theme(panel.grid.minor.x = element_line(colour = "#D3D3D3", size = 0.2))
+  }
+  
   if (mobile == FALSE) {
     plot <- plot +
       labs(
@@ -268,7 +277,7 @@ gg_hbar <- function(data,
         y = stringr::str_wrap(x_title, 30),
         caption = stringr::str_wrap(caption, 50)
       ) +
-      theme_mobile_graph()
+      theme_mobile_extra()
   }
   
   return(plot)
@@ -293,6 +302,7 @@ gg_hbar <- function(data,
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
+#' @param x_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the x scale. Defaults to FALSE.
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
 #' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
 #' @param x_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 3. 
@@ -336,16 +346,23 @@ gg_hbar <- function(data,
 #'   group_by(species, sex) %>% 
 #'   summarise(body_mass_g = mean(body_mass_g, na.rm = TRUE))  
 #' 
-#' gg_hbar_col(plot_data, body_mass_g, species, sex)
-#' 
-#' gg_hbar_col(plot_data, body_mass_g, species, sex, position = "stack")
+#' gg_hbar_col(plot_data, 
+#'             x_var = body_mass_g, 
+#'             y_var = species, 
+#'             col_var = sex)
 #' 
+#' gg_hbar_col(plot_data, 
+#'             x_var = body_mass_g, 
+#'             y_var = species, 
+#'             col_var = sex, 
+#'             position = "stack")
+#'             
 gg_hbar_col <- function(data,
                         x_var,
                         y_var,
                         col_var,
                         text_var = NULL,
-                        position = "dodge",
+                        position = NULL,
                         pal = NULL,
                         pal_rev = FALSE,
                         width = 0.75,
@@ -357,6 +374,7 @@ gg_hbar_col <- function(data,
                         subtitle_wrap = 80,
                         x_balance = FALSE,
                         x_expand = NULL,
+                        x_gridlines_minor = FALSE,
                         x_labels = waiver(),
                         x_na = TRUE,
                         x_pretty_n = 5,
@@ -417,13 +435,6 @@ gg_hbar_col <- function(data,
   if (!is.numeric(x_var_vctr)) stop("Please use a numeric x variable for a horizontal bar plot")
   if (is.numeric(col_var_vctr)) stop("Please use a categorical colour variable for a horizontal bar plot")
   
-  if (x_trans != "identity") {
-    if (position == "stack") stop("Please use position = 'dodge', if you would like to not have zero as the minimum of x scale")
-  } 
-  if (x_zero == FALSE) {
-    if (position == "stack") stop("Please use position = 'dodge', if you would like to not have zero as the minimum of x scale")
-  }
-  
   if(is.logical(y_var_vctr)) {
     data <- data %>% 
       dplyr::mutate(dplyr::across(!!y_var, ~factor(., levels = c("TRUE", "FALSE"))))
@@ -465,9 +476,6 @@ gg_hbar_col <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = mobile)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = mobile)
   
-  if (position == "stack") position2 <- "stack"
-  else if (position == "dodge") position2 <- position_dodge2(preserve = "single")
-  
   if (lubridate::is.Date(y_var_vctr)) bar_unit <- 365
   else bar_unit <- 1
   
@@ -483,21 +491,33 @@ gg_hbar_col <- function(data,
   
   if (pal_rev == FALSE) pal <- rev(pal)
   
+  if(!is.null(position)) {
+    if (!position %in% c("dodge", "stack")) stop("Please use a position of either 'stack' or 'fill'")
+  }
+  
+  if (is.null(position)) {
+    position2 <- position_dodge2(preserve = "single")
+  }
+  else position2 <- position
+
   plot <- ggplot(data) +
-    theme_hbar(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
+    theme_x_gridlines(font_family = font_family, font_size_body = font_size_body, font_size_title = font_size_title) +
     geom_col(aes(x = !!y_var, y = !!x_var, col = !!col_var, fill = !!col_var, text = !!text_var), 
              alpha = alpha, 
              size = size_line, 
              width = bar_width, 
              position = position2)
   
-  if (position == "stack") {
-    data_sum <- data %>%
-      dplyr::group_by(dplyr::across(!!y_var), .drop = FALSE) %>%
-      dplyr::summarise(dplyr::across(!!x_var, ~sum(.x, na.rm = TRUE))) %>%
-      dplyr::ungroup()
-    
-    x_var_vctr <- dplyr::pull(data_sum, !!x_var)
+  if (!is.null(position)) {
+    if (position == "stack") {
+      data_sum <- data %>%
+        dplyr::group_by(dplyr::across(!!y_var), .drop = FALSE) %>%
+        dplyr::summarise(dplyr::across(!!x_var, ~sum(.x, na.rm = TRUE))) %>%
+        dplyr::ungroup()
+      
+      x_var_vctr <- dplyr::pull(data_sum, !!x_var)
+    }
+    # else if (position == "fill") x_var_vctr <- c(0, 1)
   }
   
   if (is.numeric(y_var_vctr) | lubridate::is.Date(y_var_vctr) | lubridate::is.POSIXt(y_var_vctr) | lubridate::is.POSIXct(y_var_vctr) | lubridate::is.POSIXlt(y_var_vctr)) {
@@ -587,6 +607,11 @@ gg_hbar_col <- function(data,
       geom_hline(yintercept = 0, colour = "#323232", size = 0.3)
   }
   
+  if (x_gridlines_minor == TRUE) {
+    plot <- plot +
+      theme(panel.grid.minor.x = element_line(colour = "#D3D3D3", size = 0.2))
+  }
+  
   if(is.null(col_labels)) col_labels <- function(x) stringr::str_to_sentence(x)
 
   plot <- plot +
@@ -638,7 +663,7 @@ gg_hbar_col <- function(data,
         fill = guide_legend(ncol = 1, title = stringr::str_wrap(col_title, 20)),
         col = guide_legend(ncol = 1, title = stringr::str_wrap(col_title, 20))
       ) +
-      theme_mobile_graph()
+      theme_mobile_extra()
   }
   
   return(plot)
@@ -661,6 +686,7 @@ gg_hbar_col <- function(data,
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
+#' @param x_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the x scale. Defaults to FALSE.
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
 #' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
 #' @param x_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 3. 
@@ -700,7 +726,10 @@ gg_hbar_col <- function(data,
 #'   group_by(species, sex) %>% 
 #'   summarise(body_mass_g = mean(body_mass_g, na.rm = TRUE))  
 #' 
-#' gg_hbar_facet(plot_data, body_mass_g, sex, species)
+#' gg_hbar_facet(plot_data, 
+#'               x_var = body_mass_g, 
+#'               y_var = sex, 
+#'               facet_var = species)
 #'
 gg_hbar_facet <- function(data,
                           x_var,
@@ -717,6 +746,7 @@ gg_hbar_facet <- function(data,
                           subtitle_wrap = 80,
                           x_balance = FALSE,
                           x_expand = NULL,
+                          x_gridlines_minor = FALSE,
                           x_labels = waiver(),
                           x_na = TRUE,
                           x_pretty_n = 3,
@@ -810,7 +840,7 @@ gg_hbar_facet <- function(data,
   bar_width <- bar_unit * width
   
   plot <- ggplot(data) +
-    theme_hbar(
+    theme_x_gridlines(
       font_family = font_family,
       font_size_body = font_size_body,
       font_size_title = font_size_title
@@ -915,6 +945,11 @@ gg_hbar_facet <- function(data,
       geom_hline(yintercept = 0, colour = "#323232", size = 0.3)
   }
   
+  if (x_gridlines_minor == TRUE) {
+    plot <- plot +
+      theme(panel.grid.minor.x = element_line(colour = "#D3D3D3", size = 0.2))
+  }
+  
   if(is.null(facet_labels)) facet_labels <- as_labeller(stringr::str_to_sentence)
 
   plot <- plot +
@@ -950,6 +985,7 @@ gg_hbar_facet <- function(data,
 #' @param subtitle_wrap Number of characters to wrap the subtitle to. Defaults to 80. 
 #' @param x_balance For a numeric x variable, add balance to the x scale so that zero is in the centre of the x scale.
 #' @param x_expand A vector of range expansion constants used to add padding to the x scale, as per the ggplot2 expand argument in ggplot2 scales functions. 
+#' @param x_gridlines_minor TRUE or FALSE of whether to add minor gridlines to the x scale. Defaults to FALSE.
 #' @param x_labels A function or vector to modify x scale labels, as per the ggplot2 labels argument in ggplot2 scales functions. If NULL, categorical variable labels are converted to sentence case. Use ggplot2::waiver() to keep x labels untransformed.
 #' @param x_na TRUE or FALSE of whether to include x_var NA values. Defaults to TRUE.
 #' @param x_pretty_n For a numeric or date x variable, the desired number of intervals on the x scale, as calculated by the pretty algorithm. Defaults to 5. 
@@ -996,7 +1032,12 @@ gg_hbar_facet <- function(data,
 #'   group_by(species, sex, island) %>% 
 #'   summarise(body_mass_g = mean(body_mass_g, na.rm = TRUE))  
 #' 
-#' gg_hbar_col_facet(plot_data, body_mass_g, species, island, sex)
+#' gg_hbar_col_facet(plot_data, 
+#'                   x_var = body_mass_g, 
+#'                   y_var = species, 
+#'                   col_var = island, 
+#'                   facet_var = sex, 
+#'                   facet_na = FALSE)
 #' 
 gg_hbar_col_facet <- function(data,
                               x_var,
@@ -1004,7 +1045,7 @@ gg_hbar_col_facet <- function(data,
                               col_var,
                               facet_var,
                               text_var = NULL,
-                              position = "dodge",
+                              position = NULL,
                               pal = NULL,
                               pal_rev = FALSE,
                               width = 0.75,
@@ -1016,6 +1057,7 @@ gg_hbar_col_facet <- function(data,
                               subtitle_wrap = 80,
                               x_balance = FALSE,
                               x_expand = NULL,
+                              x_gridlines_minor = FALSE,
                               x_labels = waiver(),
                               x_na = TRUE,
                               x_pretty_n = 3,
@@ -1086,13 +1128,6 @@ gg_hbar_col_facet <- function(data,
   if (is.numeric(col_var_vctr)) stop("Please use a categorical colour variable for a horizontal bar plot")
   if (is.numeric(facet_var_vctr)) stop("Please use a categorical facet variable for a horizontal bar plot")
   
-  if (x_trans != "identity") {
-    if (position == "stack") stop("Please use position = 'dodge', if you would like to not have zero as the minimum of x scale")
-  } 
-  if (x_zero == FALSE) {
-    if (position == "stack") stop("Please use position = 'dodge', if you would like to not have zero as the minimum of x scale")
-  }
-  
   if(is.logical(y_var_vctr)) {
     data <- data %>% 
       dplyr::mutate(dplyr::across(!!y_var, ~factor(., levels = c("TRUE", "FALSE"))))
@@ -1140,9 +1175,6 @@ gg_hbar_col_facet <- function(data,
   if(is.null(font_size_title)) font_size_title <- sv_font_size_title(mobile = FALSE)
   if(is.null(font_size_body)) font_size_body <- sv_font_size_body(mobile = FALSE)
   
-  if (position == "stack") position2 <- "stack"
-  else if (position == "dodge") position2 <- position_dodge2(preserve = "single")
-  
   if (lubridate::is.Date(y_var_vctr)) bar_unit <- 365
   else bar_unit <- 1
   
@@ -1158,8 +1190,17 @@ gg_hbar_col_facet <- function(data,
   
   if (pal_rev == FALSE) pal <- rev(pal)
   
+  if(!is.null(position)) {
+    if (!position %in% c("dodge", "stack")) stop("Please use a position of either 'stack' or 'fill'")
+  }
+  
+  if (is.null(position)) {
+    position2 <- position_dodge2(preserve = "single")
+  }
+  else position2 <- position
+  
   plot <- ggplot(data) +
-    theme_hbar(
+    theme_x_gridlines(
       font_family = font_family,
       font_size_body = font_size_body,
       font_size_title = font_size_title
@@ -1170,15 +1211,18 @@ gg_hbar_col_facet <- function(data,
              width = bar_width, 
              position = position2)
   
-  if (position == "stack") {
-    data_sum <- data %>%
-      dplyr::group_by(dplyr::across(c(!!y_var, !!facet_var), .drop = FALSE)) %>%
-      dplyr::summarise(dplyr::across(!!x_var, ~sum(.x, na.rm = TRUE))) %>%
-      dplyr::ungroup()
-    
-    x_var_vctr <- dplyr::pull(data_sum, !!x_var)
-  }
-    
+    if (!is.null(position)) {
+      if (position == "stack") {
+        data_sum <- data %>%
+          dplyr::group_by(dplyr::across(c(!!y_var, !!facet_var)), .drop = FALSE) %>%
+          dplyr::summarise(dplyr::across(!!x_var, ~sum(.x, na.rm = TRUE))) %>%
+          dplyr::ungroup()
+        
+        x_var_vctr <- dplyr::pull(data_sum, !!x_var)
+      }
+      # else if (position == "fill") x_var_vctr <- seq(0, 1, 0.1)
+    }
+  
     if (facet_scales %in% c("fixed", "free_x")) {
       if (is.numeric(y_var_vctr) | lubridate::is.Date(y_var_vctr) | lubridate::is.POSIXt(y_var_vctr) | lubridate::is.POSIXct(y_var_vctr) | lubridate::is.POSIXlt(y_var_vctr)) {
         
@@ -1277,6 +1321,11 @@ gg_hbar_col_facet <- function(data,
         geom_hline(yintercept = 0, colour = "#323232", size = 0.3)
     }
     
+    if (x_gridlines_minor == TRUE) {
+      plot <- plot +
+        theme(panel.grid.minor.x = element_line(colour = "#D3D3D3", size = 0.2))
+    }
+    
     if(is.null(col_labels)) col_labels <- function(x) stringr::str_to_sentence(x)
     if(is.null(facet_labels)) facet_labels <- as_labeller(stringr::str_to_sentence)
     
