@@ -473,7 +473,7 @@ gg_point_col <- function(data,
     }
     
     data <- data %>% 
-      dplyr::mutate(dplyr::across(!!col_var, ~cut(.x, col_cuts, right = FALSE, include.lowest = TRUE), .names = "col_var2"))
+      dplyr::mutate(dplyr::across(!!col_var, ~cut(.x, col_cuts, right = FALSE, include.lowest = TRUE)))
     
     if(is.null(col_labels)) col_labels <- sv_numeric_bin_labels(col_cuts, col_labels_dp)
     
@@ -491,9 +491,6 @@ gg_point_col <- function(data,
     else pal <- pal[1:col_n]
     
     if(is.null(col_labels)) col_labels <- function(x) stringr::str_to_sentence(x)
-    
-    data <- data %>% 
-      dplyr::mutate(col_var2 = !!col_var)
   }
   
   if (pal_rev == TRUE) pal <- rev(pal)
@@ -507,7 +504,7 @@ gg_point_col <- function(data,
     coord_cartesian(clip = "off")
   
   plot <- plot +
-    geom_point(aes(x = !!x_var, y = !!y_var, col = .data$col_var2, text = !!text_var), size = size_point, alpha = alpha, position = position)
+    geom_point(aes(x = !!x_var, y = !!y_var, col = !!col_var, text = !!text_var), size = size_point, alpha = alpha, position = position)
   
   if (is.numeric(x_var_vctr) | lubridate::is.Date(x_var_vctr) | lubridate::is.POSIXt(x_var_vctr) | lubridate::is.POSIXct(x_var_vctr) | lubridate::is.POSIXlt(x_var_vctr)) {
     
@@ -1160,7 +1157,7 @@ gg_point_col_facet <-
       }
       
       data <- data %>% 
-        dplyr::mutate(dplyr::across(!!col_var, ~cut(.x, col_cuts, right = FALSE, include.lowest = TRUE), .names = "col_var2"))
+        dplyr::mutate(dplyr::across(!!col_var, ~cut(.x, col_cuts, right = FALSE, include.lowest = TRUE)))
       
       if(is.null(col_labels)) col_labels <- sv_numeric_bin_labels(col_cuts, col_labels_dp)
       
@@ -1178,9 +1175,6 @@ gg_point_col_facet <-
       else pal <- pal[1:col_n]
       
       if(is.null(col_labels)) col_labels <- function(x) stringr::str_to_sentence(x)
-      
-      data <- data %>% 
-        dplyr::mutate(col_var2 = !!col_var)
     }
     
     if (pal_rev == TRUE) pal <- rev(pal)
@@ -1192,7 +1186,7 @@ gg_point_col_facet <-
         font_size_title = font_size_title
       ) +
       coord_cartesian(clip = "off") +
-      geom_point(aes(x = !!x_var, y = !!y_var, col = .data$col_var2, text = !!text_var), size = size_point, alpha = alpha, position = position)
+      geom_point(aes(x = !!x_var, y = !!y_var, col = !!col_var, text = !!text_var), size = size_point, alpha = alpha, position = position)
     
     if (facet_scales %in% c("fixed", "free_y")) {
       if (is.numeric(x_var_vctr) | lubridate::is.Date(x_var_vctr) | lubridate::is.POSIXt(x_var_vctr) | lubridate::is.POSIXct(x_var_vctr) | lubridate::is.POSIXlt(x_var_vctr)) {
